@@ -9,18 +9,23 @@ class Foo {
         var _class;
         this.Bar = (_class = class {
             constructor(){
-                _defineProperty(this, "q", void 0);
+                _defineProperty(this, "q", void 0 // should not replace
+                );
             }
         }, _defineProperty(_class, "p", void 0), _defineProperty(_class, "p1", class {
             constructor(){
                 new.target;
             }
-        }), _defineProperty(_class, "p2", new function _target() {
+        } // should not replace
+        ), _defineProperty(_class, "p2", new function _target() {
             this.constructor;
-        }), _defineProperty(_class, "p3", function() {
+        } // should not replace
+        ), _defineProperty(_class, "p3", function() {
             void 0;
-        }), _defineProperty(_class, "p4", function _target() {
+        } // should replace
+        ), _defineProperty(_class, "p4", function _target() {
             this.constructor;
-        }), _class);
+        } // should not replace
+        ), _class);
     }
 }
